const express = require("express");
const pool = require("../config/database");
const multer = require("multer");
const path = require("path");
const fs = require("fs");


const router = express.Router();

// ตั้งค่าที่เก็บไฟล์รูป
const uploadDir = "public/uploads";
if (!fs.existsSync(uploadDir)) {
    fs.mkdirSync(uploadDir, { recursive: true });
}

// ตั้งค่า Multer สำหรับอัปโหลดรูป
const storage = multer.diskStorage({
    destination: (req, file, cb) => {
        cb(null, uploadDir);
    },
    filename: (req, file, cb) => {
        cb(null, Date.now() + path.extname(file.originalname)); 
    }
});
const upload = multer({ storage: storage });


router.get("/", async (req, res) => {
    try {
        const [products] = await pool.execute("SELECT * FROM products");
        res.render("product", { products });
    } catch (error) {
        console.error("Error fetching products:", error);
        res.status(500).send("Error loading products.");
    }
});


router.get("/add", (req, res) => {
    res.render("product_add", { product: {}, message: "" });
});


router.post("/add", upload.single("image"), async (req, res) => {
    try {
        console.log("Debugging Data:", req.body);
        console.log("File Upload:", req.file);

        const { name, price, stock, description } = req.body;
        if (!name || !price || !stock || !description || !req.file) {
            throw new Error("Missing required fields");
        }

        const imagePath = "/uploads/" + req.file.filename;

        await pool.execute("INSERT INTO products (name, price, stock, description, image_url) VALUES (?, ?, ?, ?, ?)", 
            [name, price, stock, description, imagePath]);

        console.log("Product added successfully!");
        res.redirect("/products");
    } catch (error) {
        console.error("Error adding product:", error);
        res.status(500).json({ message: "Internal Server Error", error: error.message });
    }
});



router.get("/edit/:id", async (req, res) => {
    try {
        const [rows] = await pool.execute("SELECT * FROM products WHERE id = ?", [req.params.id]);
        if (rows.length === 0) {
            return res.status(404).send("ไม่พบสินค้า");
        }
        res.render("product_edit", { product: rows[0] });
    } catch (error) {
        console.error("Error fetching product:", error);
        res.status(500).send("Error loading product.");
    }
});


router.post("/edit/:id", upload.single("image"), async (req, res) => {
    try {
        const { name, price, stock, description } = req.body;
        let imagePath = req.body.oldImage; 

        
        if (req.file) {
            imagePath = "/uploads/" + req.file.filename;
        }

        console.log("Update values:", { name, price, stock, description, imagePath, id: req.params.id });

        await pool.execute(
            "UPDATE products SET name=?, price=?, stock=?, description=?, image_url=? WHERE id=?",
            [
                name ?? null,
                price ?? null,
                stock ?? null,
                description ?? null,
                imagePath ?? null,
                req.params.id ?? null
            ]
        );

        res.redirect("/products"); 
    } catch (error) {
        console.error("Error updating product:", error);
        res.status(500).send("Error updating product.");
    }
});


router.post("/delete/:id", async (req, res) => {
    try {
        const productId = req.params.id;

        
        await pool.execute("DELETE FROM products WHERE id = ?", [productId]);

        console.log("Product deleted successfully!");
        res.redirect("/products"); 
    } catch (error) {
        console.error("Error deleting product:", error);
        res.status(500).send("Error deleting product.");
    }
});


module.exports = router;
